#ifndef PARALLEL_FLASH_H_
#define PARALLEL_FLASH_H

/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 							: Parallel_FLASH.h
	
	Purpose								: This file has include file, macros, and function declaration corresponding to 
										  Parallel_FLASH.C file
										  
	Author								: Mitesh Moonat & Harshit Gaharwar
	
	VDSP version used for testing		: VisualDSP++5.0, update 10
	
	Hardware used						: ADSP-21469, ADSP-21479, ADSP-21489, ADSP-21375, ADSP-21369 EZ-Kits 
										  and ADSP-21469, ADPS-21367, ADSP-21375 BUBs
	
	Connection details 					: See "main.C"
	
	Guidelines for change				: Comment or Uncomment the macro definition "WORD_MEMORY_USED_FOR_BYTE" based on 
										  whether the FLASH device is ab 8 bit device or 16 bit device used in byte mode
**************************************************************************************************************************/

/*************************************************************************************************************************
									Include Files
**************************************************************************************************************************/
#include "EPInit.h"
#include "math.h"
#include "string.h"
#include "stdio.h"
#include "stdlib.h"

/*************************************************************************************************************************
									Structures
**************************************************************************************************************************/
typedef struct
{
	char cManID; 		//Manufacturer ID
	char sDeviceID; 	//Device ID
	
} s_id;



typedef struct
{
	bool bUniformSectors;
	
	//Main block info
	unsigned int uiBytesPerSector;
	unsigned int uiTotalSectors;
	
	//parameter block info
	bool bTopParameterBlock;
	unsigned int uiBytesPerParameterBlock;
	unsigned int uiTotalParameterBlocks;
	
	unsigned int uiTotalBytes;
	
} s_sector_map_info;

typedef struct
{
	
	bool bWordAsByte;
	unsigned int uiSectorEraseAddSeq[5];
	unsigned int uiSectorEraseDatSeq[6];
	unsigned int uiByteProgramAddSeq[3];
	unsigned int uiByteProgramDatSeq[3];
		
} s_command_set;

typedef struct
{

	s_id 					IDInfo;
	s_sector_map_info		SectorInfo;
	s_command_set			CommandSet;
	char					ManName[20];		//Manufaturer name
	char					DeviceName[100];		//Device name
	
	
} PARALLEL_FLASH_DEVICE_INFO;

/*************************************************************************************************************************
									Global variables defined as extern
**************************************************************************************************************************/
extern PARALLEL_FLASH_DEVICE_INFO g_parallel_flash_device_info;


/*************************************************************************************************************************
									MACROs
*************************************************************************************************************************/

//Procesor specific macros

#define LDR_TEMP_BUFF_SIZE 1024

#define WORD_MEMORY_USED_FOR_BYTE

/*************************************************************************************************************************
									Function Declarations
**************************************************************************************************************************/
//Device Identification related function
void Parallel_FLASH_Read_Identification(s_id* DEVICE_INFO);
void Parallel_FLASH_Collect_Device_Info(PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);
void Parallel_FLASH_Print_Device_Info(PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);

//Erase
int Parallel_FLASH_Sector_Erase(unsigned int sector_address, PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);

//Read
unsigned char  Parallel_FLASH_Read_Byte(unsigned int uiAddress);
void Parallel_FLASH_Read_Bytes(unsigned char* cBuff, unsigned int uiStartAddress, unsigned int uiLength);

//Write
int Parallel_FLASH_Byte_Program(unsigned int uiAddress, unsigned char ucData, PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);
void Parallel_FLASH_Write_Byte(unsigned int uiAddress, unsigned char ucData, PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);
void Parallel_FLASH_Write_Bytes(unsigned char* ucBuff, unsigned int uiStartAddress, unsigned int uiLength, PARALLEL_FLASH_DEVICE_INFO* parallel_flash_device_info);

//Programming ldr file
#if !defined(__2137x__)
int Program_LDR_File_to_Parallel_FLASH(char* sLDRFilePath, unsigned int uiStartAddress, PARALLEL_FLASH_DEVICE_INFO *Parallel_FLASH_Info);
#endif
int Program_LDR_File_to_Parallel_FLASH_From_Memory(unsigned char* ucpSourceBuff, unsigned int uiLdrLength, unsigned int uiStartAddress, PARALLEL_FLASH_DEVICE_INFO *Parallel_FLASH_Info);

/************************************************************************************************************************/
#endif

/**************************************** END OF FILE*********************************************************************/
